X690Codec

Trait X690Codec 

pub trait X690Codec {
Show 229 methods // Required methods fn decode_from_slice( &self, bytes: ByteSlice<'_>, ) -> ASN1Result<(usize, X690Element)>; fn decode_boolean_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<BOOLEAN>; fn decode_bit_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<BIT_STRING>; fn decode_real_value(&self, value_bytes: ByteSlice<'_>) -> ASN1Result<REAL>; fn decode_utc_time_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<UTCTime>; fn decode_generalized_time_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<GeneralizedTime>; fn decode_duration_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<DURATION>; fn decode_bit_string(&self, el: &X690Element) -> ASN1Result<BIT_STRING>; fn decode_octet_string(&self, el: &X690Element) -> ASN1Result<OCTET_STRING>; fn decode_sequence(&self, el: &X690Element) -> ASN1Result<SEQUENCE>; fn decode_set(&self, el: &X690Element) -> ASN1Result<SET>; fn decode_object_descriptor( &self, el: &X690Element, ) -> ASN1Result<ObjectDescriptor>; fn decode_utf8_string(&self, el: &X690Element) -> ASN1Result<UTF8String>; fn decode_numeric_string( &self, el: &X690Element, ) -> ASN1Result<NumericString>; fn decode_printable_string( &self, el: &X690Element, ) -> ASN1Result<PrintableString>; fn decode_t61_string(&self, el: &X690Element) -> ASN1Result<T61String>; fn decode_videotex_string( &self, el: &X690Element, ) -> ASN1Result<VideotexString>; fn decode_ia5_string(&self, el: &X690Element) -> ASN1Result<IA5String>; fn decode_utc_time(&self, el: &X690Element) -> ASN1Result<UTCTime>; fn decode_generalized_time( &self, el: &X690Element, ) -> ASN1Result<GeneralizedTime>; fn decode_graphic_string( &self, el: &X690Element, ) -> ASN1Result<GraphicString>; fn decode_visible_string( &self, el: &X690Element, ) -> ASN1Result<VisibleString>; fn decode_general_string( &self, el: &X690Element, ) -> ASN1Result<GeneralString>; fn decode_universal_string( &self, el: &X690Element, ) -> ASN1Result<UniversalString>; fn decode_bmp_string(&self, el: &X690Element) -> ASN1Result<BMPString>; fn decode_any(&self, el: &X690Element) -> ASN1Result<ASN1Value>; fn encode_any(&self, value: &ASN1Value) -> ASN1Result<X690Element>; fn encode_bit_string(&self, value: &BIT_STRING) -> ASN1Result<X690Element>; fn encode_octet_string( &self, value: &OCTET_STRING, ) -> ASN1Result<X690Element>; fn encode_real(&self, value: &REAL) -> ASN1Result<X690Element>; fn encode_object_descriptor(&self, value: &str) -> ASN1Result<X690Element>; fn encode_utf8_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_numeric_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_printable_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_t61_string(&self, value: &T61String) -> ASN1Result<X690Element>; fn encode_videotex_string( &self, value: &VideotexString, ) -> ASN1Result<X690Element>; fn encode_ia5_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_utc_time(&self, value: &UTCTime) -> ASN1Result<X690Element>; fn encode_generalized_time( &self, value: &GeneralizedTime, ) -> ASN1Result<X690Element>; fn encode_graphic_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_visible_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_general_string(&self, value: &str) -> ASN1Result<X690Element>; fn encode_owned_universal_string( &self, value: UniversalString, ) -> ASN1Result<X690Element>; fn encode_owned_bmp_string( &self, value: BMPString, ) -> ASN1Result<X690Element>; fn encode_universal_string<T: AsRef<[u32]>>( &self, value: &T, ) -> ASN1Result<X690Element>; fn encode_bmp_string<T: AsRef<[u16]>>( &self, value: &T, ) -> ASN1Result<X690Element>; fn encode_duration(&self, value: &DURATION) -> ASN1Result<X690Element>; fn validate_boolean_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>; fn validate_bit_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>; fn validate_real_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>; fn validate_utc_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>; fn validate_generalized_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>; fn validate_duration_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>; fn validate_bit_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_octet_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_object_descriptor(&self, el: &X690Element) -> ASN1Result<()>; fn validate_utf8_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_numeric_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_printable_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_t61_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_videotex_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_ia5_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_utc_time(&self, el: &X690Element) -> ASN1Result<()>; fn validate_generalized_time(&self, el: &X690Element) -> ASN1Result<()>; fn validate_graphic_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_visible_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_general_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_universal_string(&self, el: &X690Element) -> ASN1Result<()>; fn validate_bmp_string(&self, el: &X690Element) -> ASN1Result<()>; // Provided methods fn decode_presentation_context_switching_type_id( &self, el: &X690Element, ) -> ASN1Result<PresentationContextSwitchingTypeIdentification> { ... } fn validate_presentation_context_switching_type_id( &self, id_el: &X690Element, ) -> ASN1Result<()> { ... } fn decode_from_bytes( &self, bytes: Bytes, ) -> ASN1Result<(usize, X690Element)> { ... } fn write<W>(&self, output: &mut W, el: &X690Element) -> Result<usize> where W: Write { ... } fn decode_integer_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<INTEGER> { ... } fn decode_enum_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<ENUMERATED> { ... } fn decode_octet_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<OCTET_STRING> { ... } fn decode_object_identifier_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<OBJECT_IDENTIFIER> { ... } fn decode_relative_oid_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<RELATIVE_OID> { ... } fn decode_numeric_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<NumericString> { ... } fn decode_printable_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<PrintableString> { ... } fn decode_ia5_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<IA5String> { ... } fn decode_graphic_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<GraphicString> { ... } fn decode_visible_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<VisibleString> { ... } fn decode_general_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<GeneralString> { ... } fn decode_universal_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<UniversalString> { ... } fn decode_bmp_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<BMPString> { ... } fn decode_date_value(&self, value_bytes: ByteSlice<'_>) -> ASN1Result<DATE> { ... } fn decode_time_of_day_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<TIME_OF_DAY> { ... } fn decode_date_time_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<DATE_TIME> { ... } fn decode_boolean(&self, el: &X690Element) -> ASN1Result<BOOLEAN> { ... } fn decode_integer(&self, el: &X690Element) -> ASN1Result<INTEGER> { ... } fn decode_enumerated(&self, el: &X690Element) -> ASN1Result<ENUMERATED> { ... } fn decode_null(&self, el: &X690Element) -> ASN1Result<()> { ... } fn decode_object_identifier( &self, el: &X690Element, ) -> ASN1Result<OBJECT_IDENTIFIER> { ... } fn decode_external(&self, el: &X690Element) -> ASN1Result<EXTERNAL> { ... } fn decode_instance_of(&self, el: &X690Element) -> ASN1Result<InstanceOf> { ... } fn decode_embedded_pdv(&self, el: &X690Element) -> ASN1Result<EMBEDDED_PDV> { ... } fn decode_character_string( &self, el: &X690Element, ) -> ASN1Result<CHARACTER_STRING> { ... } fn decode_relative_oid(&self, el: &X690Element) -> ASN1Result<RELATIVE_OID> { ... } fn decode_real(&self, el: &X690Element) -> ASN1Result<REAL> { ... } fn decode_date(&self, el: &X690Element) -> ASN1Result<DATE> { ... } fn decode_time_of_day(&self, el: &X690Element) -> ASN1Result<TIME_OF_DAY> { ... } fn decode_date_time(&self, el: &X690Element) -> ASN1Result<DATE_TIME> { ... } fn decode_duration(&self, el: &X690Element) -> ASN1Result<DURATION> { ... } fn decode_oid_iri(&self, el: &X690Element) -> ASN1Result<OID_IRI> { ... } fn decode_relative_oid_iri(&self, el: &X690Element) -> ASN1Result<OID_IRI> { ... } fn decode_time(&self, el: &X690Element) -> ASN1Result<TIME> { ... } fn encode_boolean(&self, value: &BOOLEAN) -> ASN1Result<X690Element> { ... } fn encode_integer(&self, value: &INTEGER) -> ASN1Result<X690Element> { ... } fn encode_enumerated(&self, value: &ENUMERATED) -> ASN1Result<X690Element> { ... } fn encode_null(&self, _value: &NULL) -> ASN1Result<X690Element> { ... } fn encode_object_identifier( &self, value: &OBJECT_IDENTIFIER, ) -> ASN1Result<X690Element> { ... } fn encode_external(&self, value: &EXTERNAL) -> ASN1Result<X690Element> { ... } fn encode_instance_of(&self, value: &INSTANCE_OF) -> ASN1Result<X690Element> { ... } fn encode_embedded_pdv( &self, value: &EMBEDDED_PDV, ) -> ASN1Result<X690Element> { ... } fn encode_character_string( &self, value: &CHARACTER_STRING, ) -> ASN1Result<X690Element> { ... } fn encode_relative_oid( &self, value: &RELATIVE_OID, ) -> ASN1Result<X690Element> { ... } fn encode_date(&self, value: &DATE) -> ASN1Result<X690Element> { ... } fn encode_time_of_day(&self, value: &TIME_OF_DAY) -> ASN1Result<X690Element> { ... } fn encode_date_time(&self, value: &DATE_TIME) -> ASN1Result<X690Element> { ... } fn encode_oid_iri(&self, value: &OID_IRI) -> ASN1Result<X690Element> { ... } fn encode_relative_oid_iri( &self, value: &OID_IRI, ) -> ASN1Result<X690Element> { ... } fn encode_time(&self, value: &TIME) -> ASN1Result<X690Element> { ... } fn validate_integer_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_numeric_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_printable_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_t61_string_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_videotex_string_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_ia5_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_utf8_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_octet_string_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_null_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_object_identifier_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_object_descriptor_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_enumerated_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_relative_object_identifier_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_graphic_string_value(&self, _: ByteSlice<'_>) -> ASN1Result<()> { ... } fn validate_visible_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_general_string_value(&self, _: ByteSlice<'_>) -> ASN1Result<()> { ... } fn validate_universal_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_bmp_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_date_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_time_of_day_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_date_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_oid_iri_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_relative_oid_iri_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()> { ... } fn validate_boolean(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_integer(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_null(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_object_identifier(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_real(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_enumerated(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_relative_object_identifier( &self, el: &X690Element, ) -> ASN1Result<()> { ... } fn validate_time(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_date(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_time_of_day(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_date_time(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_duration(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_oid_iri(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_relative_oid_iri(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_external(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_embedded_pdv(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_character_string(&self, el: &X690Element) -> ASN1Result<()> { ... } fn validate_any(&self, el: &X690Element) -> ASN1Result<()> { ... } fn write_boolean<W>(&self, output: &mut W, value: &BOOLEAN) -> Result<usize> where W: Write { ... } fn write_integer<W>(&self, output: &mut W, value: &INTEGER) -> Result<usize> where W: Write { ... } fn write_enumerated<W>( &self, output: &mut W, value: &ENUMERATED, ) -> Result<usize> where W: Write { ... } fn write_bit_string<W>( &self, output: &mut W, value: &BIT_STRING, ) -> Result<usize> where W: Write { ... } fn write_octet_string<W>( &self, output: &mut W, value: &OCTET_STRING, ) -> Result<usize> where W: Write { ... } fn write_null<W>(&self, output: &mut W, value: &NULL) -> Result<usize> where W: Write { ... } fn write_object_identifier<W>( &self, output: &mut W, value: &OBJECT_IDENTIFIER, ) -> Result<usize> where W: Write { ... } fn write_external<W>( &self, output: &mut W, value: &EXTERNAL, ) -> Result<usize> where W: Write { ... } fn write_instance_of<W>( &self, output: &mut W, value: &INSTANCE_OF, ) -> Result<usize> where W: Write { ... } fn write_real<W>(&self, output: &mut W, value: &REAL) -> Result<usize> where W: Write { ... } fn write_embedded_pdv<W>( &self, output: &mut W, value: &EMBEDDED_PDV, ) -> Result<usize> where W: Write { ... } fn write_character_string<W>( &self, output: &mut W, value: &CHARACTER_STRING, ) -> Result<usize> where W: Write { ... } fn write_relative_oid<W>( &self, output: &mut W, value: &RELATIVE_OID, ) -> Result<usize> where W: Write { ... } fn write_object_descriptor<W>( &self, output: &mut W, value: &ObjectDescriptor, ) -> Result<usize> where W: Write { ... } fn write_utf8_string<W>(&self, output: &mut W, value: &str) -> Result<usize> where W: Write { ... } fn write_numeric_string<W>( &self, output: &mut W, value: &str, ) -> Result<usize> where W: Write { ... } fn write_printable_string<W>( &self, output: &mut W, value: &str, ) -> Result<usize> where W: Write { ... } fn write_t61_string<W>( &self, output: &mut W, value: &T61String, ) -> Result<usize> where W: Write { ... } fn write_videotex_string<W>( &self, output: &mut W, value: &VideotexString, ) -> Result<usize> where W: Write { ... } fn write_ia5_string<W>( &self, output: &mut W, value: &IA5String, ) -> Result<usize> where W: Write { ... } fn write_utc_time<W>( &self, output: &mut W, value: &UTCTime, ) -> Result<usize> where W: Write { ... } fn write_generalized_time<W>( &self, output: &mut W, value: &GeneralizedTime, ) -> Result<usize> where W: Write { ... } fn write_graphic_string<W>( &self, output: &mut W, value: &GraphicString, ) -> Result<usize> where W: Write { ... } fn write_visible_string<W>( &self, output: &mut W, value: &VisibleString, ) -> Result<usize> where W: Write { ... } fn write_general_string<W>( &self, output: &mut W, value: &GeneralString, ) -> Result<usize> where W: Write { ... } fn write_universal_string<W>( &self, output: &mut W, value: &UniversalString, ) -> Result<usize> where W: Write { ... } fn write_bmp_string<W>( &self, output: &mut W, value: &BMPString, ) -> Result<usize> where W: Write { ... } fn write_date<W>(&self, output: &mut W, value: &DATE) -> Result<usize> where W: Write { ... } fn write_time_of_day<W>( &self, output: &mut W, value: &TIME_OF_DAY, ) -> Result<usize> where W: Write { ... } fn write_date_time<W>( &self, output: &mut W, value: &DATE_TIME, ) -> Result<usize> where W: Write { ... } fn write_duration<W>( &self, output: &mut W, value: &DURATION, ) -> Result<usize> where W: Write { ... } fn write_oid_iri<W>(&self, output: &mut W, value: &OID_IRI) -> Result<usize> where W: Write { ... } fn write_relative_oid_iri<W>( &self, output: &mut W, value: &OID_IRI, ) -> Result<usize> where W: Write { ... } fn write_time<W>(&self, output: &mut W, value: &TIME) -> Result<usize> where W: Write { ... } fn encode_i8(&self, value: i8) -> ASN1Result<X690Element> { ... } fn decode_i8(&self, el: &X690Element) -> ASN1Result<i8> { ... } fn validate_i8(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_u8(&self, value: u8) -> ASN1Result<X690Element> { ... } fn decode_u8(&self, el: &X690Element) -> ASN1Result<u8> { ... } fn validate_u8(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_i16(&self, value: i16) -> ASN1Result<X690Element> { ... } fn decode_i16(&self, el: &X690Element) -> ASN1Result<i16> { ... } fn validate_i16(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_u16(&self, value: u16) -> ASN1Result<X690Element> { ... } fn decode_u16(&self, el: &X690Element) -> ASN1Result<u16> { ... } fn validate_u16(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_i32(&self, value: i32) -> ASN1Result<X690Element> { ... } fn decode_i32(&self, el: &X690Element) -> ASN1Result<i32> { ... } fn validate_i32(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_u32(&self, value: u32) -> ASN1Result<X690Element> { ... } fn decode_u32(&self, el: &X690Element) -> ASN1Result<u32> { ... } fn validate_u32(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_i64(&self, value: i64) -> ASN1Result<X690Element> { ... } fn decode_i64(&self, el: &X690Element) -> ASN1Result<i64> { ... } fn validate_i64(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_u64(&self, value: u64) -> ASN1Result<X690Element> { ... } fn decode_u64(&self, el: &X690Element) -> ASN1Result<u64> { ... } fn validate_u64(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_i128(&self, value: i128) -> ASN1Result<X690Element> { ... } fn decode_i128(&self, el: &X690Element) -> ASN1Result<i128> { ... } fn validate_i128(&self, el: &X690Element) -> ASN1Result<()> { ... } fn encode_u128(&self, value: u128) -> ASN1Result<X690Element> { ... } fn decode_u128(&self, el: &X690Element) -> ASN1Result<u128> { ... } fn validate_u128(&self, el: &X690Element) -> ASN1Result<()> { ... }
}
Any codec defined in ITU-T Recommendation X.690.

Default implementations are defined where commonalities exist between BER, CER, and DER.

Required Methods

fn decode_from_slice( &self, bytes: ByteSlice<'_>, ) -> ASN1Result<(usize, X690Element)>

Decode X.690 elements from a slice of bytes

fn decode_boolean_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<BOOLEAN>

Decode a BOOLEAN from content octets

fn decode_bit_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<BIT_STRING>

Decode a BIT STRING from content octets

fn decode_real_value(&self, value_bytes: ByteSlice<'_>) -> ASN1Result<REAL>

Decode a REAL from content octets

fn decode_utc_time_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<UTCTime>

Decode a UTCTime from content octets

fn decode_generalized_time_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<GeneralizedTime>

Decode a GeneralizedTime from content octets

fn decode_duration_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<DURATION>

Decode a DURATION from content octets

fn decode_bit_string(&self, el: &X690Element) -> ASN1Result<BIT_STRING>

Decode a BIT STRING value from an X.690 encoding

fn decode_octet_string(&self, el: &X690Element) -> ASN1Result<OCTET_STRING>

Decode an OCTET STRING value from an X.690 encoding

fn decode_sequence(&self, el: &X690Element) -> ASN1Result<SEQUENCE>

Decode a SEQUENCE value from an X.690 encoding

fn decode_set(&self, el: &X690Element) -> ASN1Result<SET>

Decode a SET value from an X.690 encoding

fn decode_object_descriptor( &self, el: &X690Element, ) -> ASN1Result<ObjectDescriptor>

Decode an ObjectDescriptor value from an X.690 encoding

fn decode_utf8_string(&self, el: &X690Element) -> ASN1Result<UTF8String>

Decode a UTF8String value from an X.690 encoding

fn decode_numeric_string(&self, el: &X690Element) -> ASN1Result<NumericString>

Decode a NumericString value from an X.690 encoding

fn decode_printable_string( &self, el: &X690Element, ) -> ASN1Result<PrintableString>

Decode a PrintableString value from an X.690 encoding

fn decode_t61_string(&self, el: &X690Element) -> ASN1Result<T61String>

Decode a T61String / TeletexString value from an X.690 encoding

fn decode_videotex_string(&self, el: &X690Element) -> ASN1Result<VideotexString>

Decode a VideotexString value from an X.690 encoding

fn decode_ia5_string(&self, el: &X690Element) -> ASN1Result<IA5String>

Decode an IA5String value from an X.690 encoding

fn decode_utc_time(&self, el: &X690Element) -> ASN1Result<UTCTime>

Decode a UTCTime value from an X.690 encoding

fn decode_generalized_time( &self, el: &X690Element, ) -> ASN1Result<GeneralizedTime>

Decode a GeneralizedTime value from an X.690 encoding

fn decode_graphic_string(&self, el: &X690Element) -> ASN1Result<GraphicString>

Decode a GraphicString value from an X.690 encoding

fn decode_visible_string(&self, el: &X690Element) -> ASN1Result<VisibleString>

Decode a VisibleString / ISO646String value from an X.690 encoding

fn decode_general_string(&self, el: &X690Element) -> ASN1Result<GeneralString>

Decode a GeneralString value from an X.690 encoding

fn decode_universal_string( &self, el: &X690Element, ) -> ASN1Result<UniversalString>

Decode a UniversalString value from an X.690 encoding

fn decode_bmp_string(&self, el: &X690Element) -> ASN1Result<BMPString>

Decode a BMPString value from an X.690 encoding

fn decode_any(&self, el: &X690Element) -> ASN1Result<ASN1Value>

Decode any ASN.1 value from an X.690 encoding

fn encode_any(&self, value: &ASN1Value) -> ASN1Result<X690Element>

Encode any ASN.1 value into an X.690 encoding

fn encode_bit_string(&self, value: &BIT_STRING) -> ASN1Result<X690Element>

Encode a BIT STRING value into an X.690 encoding

fn encode_octet_string(&self, value: &OCTET_STRING) -> ASN1Result<X690Element>

Encode an OCTET STRING value into an X.690 encoding

fn encode_real(&self, value: &REAL) -> ASN1Result<X690Element>

Encode a REAL value into an X.690 encoding

fn encode_object_descriptor(&self, value: &str) -> ASN1Result<X690Element>

Encode an ObjectDescriptor value into an X.690 encoding

fn encode_utf8_string(&self, value: &str) -> ASN1Result<X690Element>

Encode a UTF8String value into an X.690 encoding

fn encode_numeric_string(&self, value: &str) -> ASN1Result<X690Element>

Encode a NumericString value into an X.690 encoding

fn encode_printable_string(&self, value: &str) -> ASN1Result<X690Element>

Encode a PrintableString value into an X.690 encoding

fn encode_t61_string(&self, value: &T61String) -> ASN1Result<X690Element>

Encode a T61String / TeletexString value into an X.690 encoding

fn encode_videotex_string( &self, value: &VideotexString, ) -> ASN1Result<X690Element>

Encode a VideotexString value into an X.690 encoding

fn encode_ia5_string(&self, value: &str) -> ASN1Result<X690Element>

Encode an IA5String value into an X.690 encoding

fn encode_utc_time(&self, value: &UTCTime) -> ASN1Result<X690Element>

Encode a UTCTime value into an X.690 encoding

fn encode_generalized_time( &self, value: &GeneralizedTime, ) -> ASN1Result<X690Element>

Encode a GeneralizedTime value into an X.690 encoding

fn encode_graphic_string(&self, value: &str) -> ASN1Result<X690Element>

Encode a GraphicString value into an X.690 encoding

fn encode_visible_string(&self, value: &str) -> ASN1Result<X690Element>

Encode a VisibleString / ISO646String value into an X.690 encoding

fn encode_general_string(&self, value: &str) -> ASN1Result<X690Element>

Encode a GeneralString value into an X.690 encoding

fn encode_owned_universal_string( &self, value: UniversalString, ) -> ASN1Result<X690Element>

Encode an owned UniversalString value into an X.690 encoding

fn encode_owned_bmp_string(&self, value: BMPString) -> ASN1Result<X690Element>

Encode an owned BMPString value into an X.690 encoding

fn encode_universal_string<T: AsRef<[u32]>>( &self, value: &T, ) -> ASN1Result<X690Element>

Encode a UniversalString value into an X.690 encoding

fn encode_bmp_string<T: AsRef<[u16]>>( &self, value: &T, ) -> ASN1Result<X690Element>

Encode a BMPString value into an X.690 encoding

fn encode_duration(&self, value: &DURATION) -> ASN1Result<X690Element>

Encode a DURATION value into an X.690 encoding

fn validate_boolean_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded BOOLEAN value from content octets

fn validate_bit_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded BIT STRING value from content octets

fn validate_real_value(&self, content_octets: ByteSlice<'_>) -> ASN1Result<()>

Validate an encoded REAL value from content octets

fn validate_utc_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded UTCTime value from content octets

fn validate_generalized_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded GeneralizedTime value from content octets

fn validate_duration_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded DURATION value from content octets

fn validate_bit_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded BIT STRING

fn validate_octet_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded OCTET STRING

fn validate_object_descriptor(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded ObjectDescriptor

fn validate_utf8_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded UTF8String

fn validate_numeric_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded NumericString

fn validate_printable_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded PrintableString

fn validate_t61_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded T61String / TeletexString

fn validate_videotex_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded VideotexString

fn validate_ia5_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded IA5String

fn validate_utc_time(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded UTCTime

fn validate_generalized_time(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded GeneralizedTime

fn validate_graphic_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded GraphicString

fn validate_visible_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded VisibleString / ISO646String

fn validate_general_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded GeneralString

fn validate_universal_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded UniversalString

fn validate_bmp_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded BMPString

Provided Methods

fn decode_presentation_context_switching_type_id( &self, el: &X690Element, ) -> ASN1Result<PresentationContextSwitchingTypeIdentification>

Decode the identification field of a context switching type, such as a EMBEDDED PDV or CHARACTER STRING.

fn validate_presentation_context_switching_type_id( &self, id_el: &X690Element, ) -> ASN1Result<()>

Validate the identification field of a context switching type, such as a EMBEDDED PDV or CHARACTER STRING.

fn decode_from_bytes(&self, bytes: Bytes) -> ASN1Result<(usize, X690Element)>

Decode X.690 elements from a bytes::Bytes

fn write<W>(&self, output: &mut W, el: &X690Element) -> Result<usize>
where W: Write,

Write an X.690 element

fn decode_integer_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<INTEGER>

Decode an INTEGER from content octets

fn decode_enum_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<ENUMERATED>

Decode an ENUMERATED from content octets

fn decode_octet_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<OCTET_STRING>

Decode an OCTET STRING from content octets

fn decode_object_identifier_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<OBJECT_IDENTIFIER>

Decode an OBJECT IDENTIFIER from content octets

fn decode_relative_oid_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<RELATIVE_OID>

Decode a RELATIVE-OID from content octets

fn decode_numeric_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<NumericString>

Decode a NumericString from content octets

fn decode_printable_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<PrintableString>

Decode a PrintableString from content octets

fn decode_ia5_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<IA5String>

Decode an IA5String from content octets

fn decode_graphic_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<GraphicString>

Decode a GraphicString from content octets

fn decode_visible_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<VisibleString>

Decode a VisibleString / ISO646String from content octets

fn decode_general_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<GeneralString>

Decode a GeneralString from content octets

fn decode_universal_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<UniversalString>

Decode a UniversalString from content octets

fn decode_bmp_string_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<BMPString>

Decode a BMPString from content octets

fn decode_date_value(&self, value_bytes: ByteSlice<'_>) -> ASN1Result<DATE>

Decode a DATE from content octets

fn decode_time_of_day_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<TIME_OF_DAY>

Decode a TIME-OF-DAY from content octets

fn decode_date_time_value( &self, value_bytes: ByteSlice<'_>, ) -> ASN1Result<DATE_TIME>

Decode a DATE-TIME from content octets

fn decode_boolean(&self, el: &X690Element) -> ASN1Result<BOOLEAN>

Decode a BOOLEAN value from an X.690 encoding

fn decode_integer(&self, el: &X690Element) -> ASN1Result<INTEGER>

Decode an INTEGER value from an X.690 encoding

fn decode_enumerated(&self, el: &X690Element) -> ASN1Result<ENUMERATED>

Decode an ENUMERATED value from an X.690 encoding

fn decode_null(&self, el: &X690Element) -> ASN1Result<()>

Decode a NULL value from an X.690 encoding

fn decode_object_identifier( &self, el: &X690Element, ) -> ASN1Result<OBJECT_IDENTIFIER>

Decode an OBJECT IDENTIFIER value from an X.690 encoding

fn decode_external(&self, el: &X690Element) -> ASN1Result<EXTERNAL>

Decode an EXTERNAL value from an X.690 encoding

fn decode_instance_of(&self, el: &X690Element) -> ASN1Result<InstanceOf>

Decode an INSTANCE OF value from an X.690 encoding

fn decode_embedded_pdv(&self, el: &X690Element) -> ASN1Result<EMBEDDED_PDV>

Decode an EMBEDDED PDV value from an X.690 encoding

fn decode_character_string( &self, el: &X690Element, ) -> ASN1Result<CHARACTER_STRING>

Decode a CHARACTER STRING value from an X.690 encoding

fn decode_relative_oid(&self, el: &X690Element) -> ASN1Result<RELATIVE_OID>

Decode a RELATIVE-OID value from an X.690 encoding

fn decode_real(&self, el: &X690Element) -> ASN1Result<REAL>

Decode a REAL value from an X.690 encoding

fn decode_date(&self, el: &X690Element) -> ASN1Result<DATE>

Decode a DATE value from an X.690 encoding

fn decode_time_of_day(&self, el: &X690Element) -> ASN1Result<TIME_OF_DAY>

Decode a TIME-OF-DAY value from an X.690 encoding

fn decode_date_time(&self, el: &X690Element) -> ASN1Result<DATE_TIME>

Decode a DATE-TIME value from an X.690 encoding

fn decode_duration(&self, el: &X690Element) -> ASN1Result<DURATION>

Decode a DURATION value from an X.690 encoding

fn decode_oid_iri(&self, el: &X690Element) -> ASN1Result<OID_IRI>

Decode an OID-IRI value from an X.690 encoding

fn decode_relative_oid_iri(&self, el: &X690Element) -> ASN1Result<OID_IRI>

Decode a RELATIVE-OID-IRI value from an X.690 encoding

fn decode_time(&self, el: &X690Element) -> ASN1Result<TIME>

Decode a TIME value from an X.690 encoding

fn encode_boolean(&self, value: &BOOLEAN) -> ASN1Result<X690Element>

Encode a BOOLEAN value into an X.690 encoding

fn encode_integer(&self, value: &INTEGER) -> ASN1Result<X690Element>

Encode an INTEGER value into an X.690 encoding

fn encode_enumerated(&self, value: &ENUMERATED) -> ASN1Result<X690Element>

Encode an ENUMERATED value into an X.690 encoding

fn encode_null(&self, _value: &NULL) -> ASN1Result<X690Element>

Encode a NULL value into an X.690 encoding

fn encode_object_identifier( &self, value: &OBJECT_IDENTIFIER, ) -> ASN1Result<X690Element>

Encode an OBJECT IDENTIFIER value into an X.690 encoding

fn encode_external(&self, value: &EXTERNAL) -> ASN1Result<X690Element>

Encode an EXTERNAL value into an X.690 encoding

fn encode_instance_of(&self, value: &INSTANCE_OF) -> ASN1Result<X690Element>

Encode an INSTANCE OF value into an X.690 encoding

fn encode_embedded_pdv(&self, value: &EMBEDDED_PDV) -> ASN1Result<X690Element>

Encode an EMBEDDED PDV value into an X.690 encoding

fn encode_character_string( &self, value: &CHARACTER_STRING, ) -> ASN1Result<X690Element>

Encode a CHARACTER STRING value into an X.690 encoding

fn encode_relative_oid(&self, value: &RELATIVE_OID) -> ASN1Result<X690Element>

Encode a RELATIVE-OID value into an X.690 encoding

fn encode_date(&self, value: &DATE) -> ASN1Result<X690Element>

Encode a DATE value into an X.690 encoding

fn encode_time_of_day(&self, value: &TIME_OF_DAY) -> ASN1Result<X690Element>

Encode a TIME-OF-DAY value into an X.690 encoding

fn encode_date_time(&self, value: &DATE_TIME) -> ASN1Result<X690Element>

Encode a DATE-TIME value into an X.690 encoding

fn encode_oid_iri(&self, value: &OID_IRI) -> ASN1Result<X690Element>

Encode an OID-IRI value into an X.690 encoding

fn encode_relative_oid_iri(&self, value: &OID_IRI) -> ASN1Result<X690Element>

Encode a RELATIVE-OID-IRI value into an X.690 encoding

fn encode_time(&self, value: &TIME) -> ASN1Result<X690Element>

Encode a TIME value into an X.690 encoding

fn validate_integer_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded INTEGER value from content octets

fn validate_time_value(&self, content_octets: ByteSlice<'_>) -> ASN1Result<()>

Validate an encoded TIME value from content octets

fn validate_numeric_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded NumericString value from content octets

fn validate_printable_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded PrintableString value from content octets

fn validate_t61_string_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded T61String / TeletexString value from content octets

fn validate_videotex_string_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded VideotexString value from content octets

fn validate_ia5_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded IA5String value from content octets

fn validate_utf8_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded UTF8String value from content octets

fn validate_octet_string_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded OCTET STRING value from content octets

fn validate_null_value(&self, content_octets: ByteSlice<'_>) -> ASN1Result<()>

Validate an encoded NULL value from content octets

fn validate_object_identifier_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded OBJECT IDENTIFIER value from content octets

fn validate_object_descriptor_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded ObjectDescriptor value from content octets

fn validate_enumerated_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded ENUMERATED value from content octets

fn validate_relative_object_identifier_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded RELATIVE-OID value from content octets

fn validate_graphic_string_value(&self, _: ByteSlice<'_>) -> ASN1Result<()>

Validate an encoded GraphicString value from content octets

fn validate_visible_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded VisibleString value from content octets

fn validate_general_string_value(&self, _: ByteSlice<'_>) -> ASN1Result<()>

Validate an encoded GeneralString value from content octets

There’s no validation here, because a GeneralString can be basically anything.

fn validate_universal_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded UniversalString value from content octets

fn validate_bmp_string_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded BMPString value from content octets

fn validate_date_value(&self, content_octets: ByteSlice<'_>) -> ASN1Result<()>

Validate an encoded DATE value from content octets

fn validate_time_of_day_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded TIME-OF-DAY value from content octets

fn validate_date_time_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded DATE-TIME value from content octets

fn validate_oid_iri_value( &self, content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded OID-IRI value from content octets

fn validate_relative_oid_iri_value( &self, _content_octets: ByteSlice<'_>, ) -> ASN1Result<()>

Validate an encoded RELATIVE-OID-IRI value from content octets

fn validate_boolean(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded BOOLEAN

fn validate_integer(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded INTEGER

fn validate_null(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded NULL

fn validate_object_identifier(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded OBJECT IDENTIFIER

fn validate_real(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded REAL

fn validate_enumerated(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded ENUMERATED

fn validate_relative_object_identifier( &self, el: &X690Element, ) -> ASN1Result<()>

Validate an encoded RELATIVE-OID

fn validate_time(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded TIME

fn validate_date(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded DATE

fn validate_time_of_day(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded TIME-OF-DAY

fn validate_date_time(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded DATE-TIME

fn validate_duration(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded DURATION

fn validate_oid_iri(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded OID-IRI

fn validate_relative_oid_iri(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded RELATIVE-OID-IRI

fn validate_external(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded EXTERNAL

fn validate_embedded_pdv(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded EMBEDDED PDV

fn validate_character_string(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded CHARACTER STRING

fn validate_any(&self, el: &X690Element) -> ASN1Result<()>

Validate any encoded ASN.1 value

fn write_boolean<W>(&self, output: &mut W, value: &BOOLEAN) -> Result<usize>
where W: Write,

Write a BOOLEAN value as an X.690 encoding to a writable stream

fn write_integer<W>(&self, output: &mut W, value: &INTEGER) -> Result<usize>
where W: Write,

Write an INTEGER value as an X.690 encoding to a writable stream

fn write_enumerated<W>( &self, output: &mut W, value: &ENUMERATED, ) -> Result<usize>
where W: Write,

Write an ENUMERATED value as an X.690 encoding to a writable stream

fn write_bit_string<W>( &self, output: &mut W, value: &BIT_STRING, ) -> Result<usize>
where W: Write,

Write a BIT STRING value as an X.690 encoding to a writable stream

fn write_octet_string<W>( &self, output: &mut W, value: &OCTET_STRING, ) -> Result<usize>
where W: Write,

Write an OCTET STRING value as an X.690 encoding to a writable stream

fn write_null<W>(&self, output: &mut W, value: &NULL) -> Result<usize>
where W: Write,

Write a NULL value as an X.690 encoding to a writable stream

fn write_object_identifier<W>( &self, output: &mut W, value: &OBJECT_IDENTIFIER, ) -> Result<usize>
where W: Write,

Write an OBJECT IDENTIFIER value as an X.690 encoding to a writable stream

fn write_external<W>(&self, output: &mut W, value: &EXTERNAL) -> Result<usize>
where W: Write,

Write an EXTERNAL value as an X.690 encoding to a writable stream

fn write_instance_of<W>( &self, output: &mut W, value: &INSTANCE_OF, ) -> Result<usize>
where W: Write,

Write an INSTANCE OF value as an X.690 encoding to a writable stream

fn write_real<W>(&self, output: &mut W, value: &REAL) -> Result<usize>
where W: Write,

Write a REAL value as an X.690 encoding to a writable stream

fn write_embedded_pdv<W>( &self, output: &mut W, value: &EMBEDDED_PDV, ) -> Result<usize>
where W: Write,

Write an EMBEDDED PDV value as an X.690 encoding to a writable stream

fn write_character_string<W>( &self, output: &mut W, value: &CHARACTER_STRING, ) -> Result<usize>
where W: Write,

Write a CHARACTER STRING value as an X.690 encoding to a writable stream

fn write_relative_oid<W>( &self, output: &mut W, value: &RELATIVE_OID, ) -> Result<usize>
where W: Write,

Write a RELATIVE-OID value as an X.690 encoding to a writable stream

fn write_object_descriptor<W>( &self, output: &mut W, value: &ObjectDescriptor, ) -> Result<usize>
where W: Write,

Write an ObjectDescriptor value as an X.690 encoding to a writable stream

fn write_utf8_string<W>(&self, output: &mut W, value: &str) -> Result<usize>
where W: Write,

Write a UTF8String value as an X.690 encoding to a writable stream

fn write_numeric_string<W>(&self, output: &mut W, value: &str) -> Result<usize>
where W: Write,

Write a NumericString value as an X.690 encoding to a writable stream

fn write_printable_string<W>( &self, output: &mut W, value: &str, ) -> Result<usize>
where W: Write,

Write a PrintableString value as an X.690 encoding to a writable stream

fn write_t61_string<W>( &self, output: &mut W, value: &T61String, ) -> Result<usize>
where W: Write,

Write a T61String / TeletexString value as an X.690 encoding to a writable stream

fn write_videotex_string<W>( &self, output: &mut W, value: &VideotexString, ) -> Result<usize>
where W: Write,

Write a VideotexString value as an X.690 encoding to a writable stream

fn write_ia5_string<W>( &self, output: &mut W, value: &IA5String, ) -> Result<usize>
where W: Write,

Write an IA5String value as an X.690 encoding to a writable stream

fn write_utc_time<W>(&self, output: &mut W, value: &UTCTime) -> Result<usize>
where W: Write,

Write a UTCTime value as an X.690 encoding to a writable stream

fn write_generalized_time<W>( &self, output: &mut W, value: &GeneralizedTime, ) -> Result<usize>
where W: Write,

Write a GeneralizedTime value as an X.690 encoding to a writable stream

fn write_graphic_string<W>( &self, output: &mut W, value: &GraphicString, ) -> Result<usize>
where W: Write,

Write a GraphicString value as an X.690 encoding to a writable stream

fn write_visible_string<W>( &self, output: &mut W, value: &VisibleString, ) -> Result<usize>
where W: Write,

Write a VisibleString / ISO646String value as an X.690 encoding to a writable stream

fn write_general_string<W>( &self, output: &mut W, value: &GeneralString, ) -> Result<usize>
where W: Write,

Write a GeneralString value as an X.690 encoding to a writable stream

fn write_universal_string<W>( &self, output: &mut W, value: &UniversalString, ) -> Result<usize>
where W: Write,

Write a UniversalString value as an X.690 encoding to a writable stream

fn write_bmp_string<W>( &self, output: &mut W, value: &BMPString, ) -> Result<usize>
where W: Write,

Write a BMPString value as an X.690 encoding to a writable stream

fn write_date<W>(&self, output: &mut W, value: &DATE) -> Result<usize>
where W: Write,

Write a DATE value as an X.690 encoding to a writable stream

fn write_time_of_day<W>( &self, output: &mut W, value: &TIME_OF_DAY, ) -> Result<usize>
where W: Write,

Write a TIME-OF-DAY value as an X.690 encoding to a writable stream

fn write_date_time<W>(&self, output: &mut W, value: &DATE_TIME) -> Result<usize>
where W: Write,

Write a DATE-TIME value as an X.690 encoding to a writable stream

fn write_duration<W>(&self, output: &mut W, value: &DURATION) -> Result<usize>
where W: Write,

Write a DURATION value as an X.690 encoding to a writable stream

fn write_oid_iri<W>(&self, output: &mut W, value: &OID_IRI) -> Result<usize>
where W: Write,

Write an OID-IRI value as an X.690 encoding to a writable stream

fn write_relative_oid_iri<W>( &self, output: &mut W, value: &OID_IRI, ) -> Result<usize>
where W: Write,

Write a RELATIVE-OID-IRI value as an X.690 encoding to a writable stream

fn write_time<W>(&self, output: &mut W, value: &TIME) -> Result<usize>
where W: Write,

Write a TIME value as an X.690 encoding to a writable stream

fn encode_i8(&self, value: i8) -> ASN1Result<X690Element>

Encode an i8 value as an X.690 encoding of an INTEGER

fn decode_i8(&self, el: &X690Element) -> ASN1Result<i8>

Decode an i8 from an X.690-encoded INTEGER

fn validate_i8(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded i8

fn encode_u8(&self, value: u8) -> ASN1Result<X690Element>

Encode a u8 value as an X.690 encoding of an INTEGER

fn decode_u8(&self, el: &X690Element) -> ASN1Result<u8>

Decode a u8 from an X.690-encoded INTEGER

fn validate_u8(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded u8

fn encode_i16(&self, value: i16) -> ASN1Result<X690Element>

Encode an i16 value as an X.690 encoding of an INTEGER

fn decode_i16(&self, el: &X690Element) -> ASN1Result<i16>

Decode an i16 from an X.690-encoded INTEGER

fn validate_i16(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded i16

fn encode_u16(&self, value: u16) -> ASN1Result<X690Element>

Encode a u16 value as an X.690 encoding of an INTEGER

fn decode_u16(&self, el: &X690Element) -> ASN1Result<u16>

Decode a u16 from an X.690-encoded INTEGER

fn validate_u16(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded u16

fn encode_i32(&self, value: i32) -> ASN1Result<X690Element>

Encode an i32 value as an X.690 encoding of an INTEGER

fn decode_i32(&self, el: &X690Element) -> ASN1Result<i32>

Decode an i32 from an X.690-encoded INTEGER

fn validate_i32(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded i32

fn encode_u32(&self, value: u32) -> ASN1Result<X690Element>

Encode a u32 value as an X.690 encoding of an INTEGER

fn decode_u32(&self, el: &X690Element) -> ASN1Result<u32>

Decode a u32

fn validate_u32(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded u32

fn encode_i64(&self, value: i64) -> ASN1Result<X690Element>

Encode an i64 value as an X.690 encoding of an INTEGER

fn decode_i64(&self, el: &X690Element) -> ASN1Result<i64>

Decode an i64 from an X.690-encoded INTEGER

fn validate_i64(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded i64

fn encode_u64(&self, value: u64) -> ASN1Result<X690Element>

Encode a u64 value as an X.690 encoding of an INTEGER

fn decode_u64(&self, el: &X690Element) -> ASN1Result<u64>

Decode a u64 from an X.690-encoded INTEGER

fn validate_u64(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded u64

fn encode_i128(&self, value: i128) -> ASN1Result<X690Element>

Encode an i128 value as an X.690 encoding of an INTEGER

fn decode_i128(&self, el: &X690Element) -> ASN1Result<i128>

Decode an i128 from an X.690-encoded INTEGER

fn validate_i128(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded i128

fn encode_u128(&self, value: u128) -> ASN1Result<X690Element>

Encode a u128 value as an X.690 encoding of an INTEGER

fn decode_u128(&self, el: &X690Element) -> ASN1Result<u128>

Decode a u128 from an X.690-encoded INTEGER

fn validate_u128(&self, el: &X690Element) -> ASN1Result<()>

Validate an encoded u128

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors