pub type ComponentHandlers<'a> = HashMap<&'a str, ComponentHandler<'a>>;Expand description
A mapping of component names to their handler functions.
Aliased Type
pub struct ComponentHandlers<'a> { /* private fields */ }pub type ComponentHandlers<'a> = HashMap<&'a str, ComponentHandler<'a>>;A mapping of component names to their handler functions.
pub struct ComponentHandlers<'a> { /* private fields */ }